@@ -1,6 +1,7 @@
 convert_factor <-
 function(data,vars){
   for (var in vars){
-    data[,var]<<-factor(data[,var])
+    data[,var]=factor(data[,var])
   }
+  data
 }
